# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class KuaishouWeb:

    def __init__(self, client: APIClient):
        self.client = client

    # 获取单个作品数据 (Fetch Single Video)
    async def fetch_one_video(self, photo_id: str):
        endpoint = "/api/v1/kuaishou/web/fetch_one_video"
        data = await self.client.fetch_get_json(f"{endpoint}?photo_id={photo_id}")
        return data

    # 快手单一视频查询接口V2 (Kuaishou Single Video Query API V2)
    async def fetch_one_video_v2(self, photo_id: str, isLongVideo: bool = False):
        endpoint = "/api/v1/kuaishou/web/fetch_one_video_v2"
        data = await self.client.fetch_get_json(f"{endpoint}?photo_id={photo_id}&isLongVideo={isLongVideo}")
        return data

    # 根据链接获取单个作品数据 (Fetch Single Video By URL)
    async def fetch_one_video_by_url(self, url: str):
        endpoint = "/api/v1/kuaishou/web/fetch_one_video_by_url"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 根据链接获取单个作品数据V2 (Fetch Single Video By URL V2)
    async def fetch_one_video_by_url_v2(self, url: str):
        endpoint = "/api/v1/kuaishou/web/fetch_one_video_by_url_v2"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 获取单个作品评论数据 (Fetch Single Video Comment Data)
    async def fetch_one_video_comment(self, photo_id: str, pcursor: str = None):
        endpoint = "/api/v1/kuaishou/web/fetch_one_video_comment"
        data = await self.client.fetch_get_json(f"{endpoint}?photo_id={photo_id}&pcursor={pcursor}")
        return data

    # 获取主页视频数据 (Fetch Home Page Video Data)
    async def fetch_home_page_video(self, user_id: str, pcursor: str = None):
        endpoint = "/api/v1/kuaishou/web/fetch_home_page_video"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}&pcursor={pcursor}")
        return data

    # 获取主页信息数据 (Fetch Home Page Info Data)
    async def fetch_home_page_info(self, user_id: str):
        endpoint = "/api/v1/kuaishou/web/fetch_home_page_info"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}")
        return data


# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class TwitterWeb:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # Fetch tweet detail | 获取推文详情
    async def fetch_tweet_detail(self, focalTweetId: str):
        endpoint = "/api/v1/twitter/web/fetch_tweet_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?focalTweetId={focalTweetId}")
        return data

    # Fetch user profile | 获取用户资料
    async def fetch_user_profile(self, screen_name: str):
        endpoint = "/api/v1/twitter/web/fetch_user_profile"
        data = await self.client.fetch_get_json(f"{endpoint}?screen_name={screen_name}")
        return data

    # Fetch user post tweet | 获取用户发帖
    async def fetch_user_post_tweet(self, userId: str, count: int = 20, cursor: str = None):
        endpoint = "/api/v1/twitter/web/fetch_user_post_tweet"
        data = await self.client.fetch_get_json(f"{endpoint}?userId={userId}&count={count}&cursor={cursor}")
        return data



# 导入API SDK Client类

from tikhub.http_client.api_client import APIClient

# 标记已废弃的方法
from tikhub.http_client.deprecated import deprecated


class XiguaAppV2:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 获取单个作品数据 | Get single video data
    async def fetch_one_video(self, item_id: str):
        endpoint = f"/api/v1/xigua/app/v2/fetch_one_video"
        data = await self.client.fetch_get_json(f"{endpoint}?item_id={item_id}")
        return data

    # 视频评论列表 | Video comment list
    async def fetch_video_comment_list(self, item_id: str, offset: int = 0, count: int = 20):
        endpoint = f"/api/v1/xigua/app/v2/fetch_video_comment_list"
        data = await self.client.fetch_get_json(f"{endpoint}?item_id={item_id}&offset={offset}&count={count}")
        return data

    # 搜索视频 | Search video
    async def search_video(self, keyword: str, offset: int = 0, order_type: str = None, min_duration: int = None, max_duration: int = None):
        endpoint = f"/api/v1/xigua/app/v2/search_video"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&order_type={order_type}&min_duration={min_duration}&max_duration={max_duration}")
        return data

    # 个人信息 | Personal information
    async def fetch_user_info(self, user_id: str):
        endpoint = f"/api/v1/xigua/app/v2/fetch_user_info"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}")
        return data

    # 获取个人作品列表 | Get user post list
    async def fetch_user_post_list(self, user_id: str, max_behot_time: str = None):
        endpoint = f"/api/v1/xigua/app/v2/fetch_user_post_list"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}&max_behot_time={max_behot_time}")
        return data


if __name__ == "__main__":
    import asyncio


    async def main():
        client = APIClient(base_url="http://127.0.0.1:8000", client_headers={
            "Authorization": "Bearer l7sVQFh64V8ltC8fzEaNtWE60zVSopDLlpVX62fArT1FznsPds9+2RGoXw=="})

        xigua_app_v2 = XiguaAppV2(client)

    asyncio.run(main())



# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class XiaohongshuWeb:
    def __init__(self, client: APIClient):
        self.client = client

    # 获取笔记信息
    async def get_note_info(self, note_id: str):
        endpoint = "/api/v1/xiaohongshu/web/get_note_info"
        data = await self.client.fetch_get_json(f"{endpoint}?note_id={note_id}")
        return data

    # 获取用户信息
    async def get_user_info(self, user_id: str):
        endpoint = "/api/v1/xiaohongshu/web/get_user_info"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}")
        return data

    # 搜索笔记
    async def search_notes(self, keyword: str, page: int = 1, sort: str = "general", noteType: str = "_0"):
        endpoint = "/api/v1/xiaohongshu/web/search_notes"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&page={page}&sort={sort}&noteType={noteType}")
        return data

    # 获取用户的笔记
    async def get_user_notes(self, user_id: str, lastCursor: str = None):
        endpoint = "/api/v1/xiaohongshu/web/get_user_notes"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}&lastCursor={lastCursor}")
        return data

    # 获取笔记评论
    async def get_note_comments(self, note_id: str, lastCursor: str = None):
        endpoint = "/api/v1/xiaohongshu/web/get_note_comments"
        data = await self.client.fetch_get_json(f"{endpoint}?note_id={note_id}&lastCursor={lastCursor}")
        return data

    # 获取笔记评论回复
    async def get_note_comment_replies(self, note_id: str, comment_id: str, lastCursor: str = None):
        endpoint = "/api/v1/xiaohongshu/web/get_note_comment_replies"
        data = await self.client.fetch_get_json(f"{endpoint}?note_id={note_id}&comment_id={comment_id}&lastCursor={lastCursor}")
        return data

    # 搜索用户
    async def search_users(self, keyword: str, page: int = 1):
        endpoint = "/api/v1/xiaohongshu/web/search_users"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&page={page}")
        return data



# import SDK Version
from tikhub import version

# http_client
from tikhub.http_client.api_client import APIClient

# TikHub
from tikhub.api.v1.endpoints.tikhub.tikhub_user import TikHubUser

# Douyin
from tikhub.api.v1.endpoints.douyin.web.douyin_web import DouyinWeb
from tikhub.api.v1.endpoints.douyin.app.douyin_app_v1 import DouyinAppV1
from tikhub.api.v1.endpoints.douyin.app.douyin_app_v2 import DouyinAppV2
from tikhub.api.v1.endpoints.douyin.app.douyin_app_v3 import DouyinAppV3

# TikTok
from tikhub.api.v1.endpoints.tiktok.web.tiktok_web import TikTokWeb
from tikhub.api.v1.endpoints.tiktok.app.tiktok_app_v2 import TikTokAppV2
from tikhub.api.v1.endpoints.tiktok.app.tiktok_app_v3 import TikTokAppV3

# Instagram
from tikhub.api.v1.endpoints.instagram.web.instagram_web import InstagramWeb

# Weibo
from tikhub.api.v1.endpoints.weibo.web.weibo_web import WeiboWeb

# Captcha Solver
from tikhub.api.v1.endpoints.captcha.captcha_solver import CaptchaSolver

# Xigua Video APP V2
from tikhub.api.v1.endpoints.xigua.app.xigua_app_v2 import XiguaAppV2

# XiaoHongShu Web
from tikhub.api.v1.endpoints.xiaohongshu.web.xiaohongshu_web import XiaohongshuWeb

# KuaiShou Web
from tikhub.api.v1.endpoints.kuaishou.web.kuaishou_web import KuaishouWeb

# YouTube Web
from tikhub.api.v1.endpoints.youtube.web.youtube_web import YouTubeWeb

# Net Ease Cloud Music
from tikhub.api.v1.endpoints.net_ease_cloud_music.app.net_ease_cloud_music_app_v1 import NetEaseCloudMusicAppV1

# Hybrid Parsing
from tikhub.api.v1.endpoints.hybrid_parsing.hybrid_parsing import HybridParsing

# Twitter Web
from tikhub.api.v1.endpoints.twitter.web.twitter_web import TwitterWeb


class Client:
    def __init__(self,
                 base_url: str = 'https://api.tikhub.io',
                 api_key: str = None,
                 proxies: dict = None,
                 max_retries: int = 3,
                 max_connections: int = 50,
                 timeout: int = 60,
                 max_tasks: int = 50,
                 custom_user_agent: str = None,
                 ):
        # Base URL
        self.base_url = base_url

        # API Key
        self.api_key = api_key
        if not self.api_key:
            raise RuntimeError("API Key is required to use the SDK. | 需要API Key才能使用SDK。")

        # Version
        self.version = str(version)

        # API Client
        self.client = APIClient(
            base_url=self.base_url,
            client_headers={
                "User-Agent": f"TikHub-API-SDK-Python/{self.version}" if not custom_user_agent else custom_user_agent,
                "X-SDK-Version": f"{self.version}",
                "Authorization": f"Bearer {self.api_key}"
            },
            proxies=proxies,
            max_retries=max_retries,
            max_connections=max_connections,
            timeout=timeout,
            max_tasks=max_tasks
        )

        # TikHub
        self.TikHubUser = TikHubUser(self.client)

        # Douyin
        self.DouyinWeb = DouyinWeb(self.client)
        self.DouyinAppV1 = DouyinAppV1(self.client)
        self.DouyinAppV2 = DouyinAppV2(self.client)
        self.DouyinAppV3 = DouyinAppV3(self.client)

        # TikTok
        self.TikTokWeb = TikTokWeb(self.client)
        self.TikTokAppV2 = TikTokAppV2(self.client)
        self.TikTokAppV3 = TikTokAppV3(self.client)

        # Instagram
        self.InstagramWeb = InstagramWeb(self.client)

        # Weibo
        self.WeiboWeb = WeiboWeb(self.client)

        # Captcha Solver
        self.CaptchaSolver = CaptchaSolver(self.client)

        # Xigua Video APP V2
        self.XiguaAppV2 = XiguaAppV2(self.client)

        # XiaoHongShu Web
        self.XiaohongshuWeb = XiaohongshuWeb(self.client)

        # KuaiShou Web
        self.KuaishouWeb = KuaishouWeb(self.client)

        # YouTube Web
        self.YouTubeWeb = YouTubeWeb(self.client)

        # Net Ease Cloud Music
        self.NetEaseCloudMusicAppV1 = NetEaseCloudMusicAppV1(self.client)

        # Twitter Web
        self.TwitterWeb = TwitterWeb(self.client)

        # Hybrid Parsing
        self.HybridParsing = HybridParsing(self.client)

    """
    [中文]
    
    这些代码用于实现异步上下文管理器，使得类的实例可以与 async with 语句一起使用，从而在进入和退出时自动处理资源的初始化和清理。
    
    例如：
    async with Client(api_key=api_key) as client:
        pass
        
    这样在退出时会自动调用 __aexit__ 方法，关闭 client。
    
    [English]
    
    This code is used to implement an asynchronous context manager, 
    which allows instances of a class to be used with the async with statement, 
    automatically handling the initialization and cleanup of resources when entering and exiting.
    
    For example:
    async with Client(api_key=api_key) as client:
        pass
        
    This way, the __aexit__ method is automatically called when exiting, closing the client.
    """

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        await self.client.close()


if __name__ == '__main__':
    # Example
    api_key = "YOUR_API_KEY"
    client = Client(api_key=api_key)



# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class YouTubeWeb:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 获取视频信息 | Get video information
    async def get_video_info(self, id: str):
        endpoint = "/api/v1/youtube/web/get_video_info"
        data = await self.client.fetch_get_json(f"{endpoint}?id={id}")
        return data

    # 获取视频字幕 | Get video subtitles
    async def get_video_subtitles(self, id: str, format: str = "json3"):
        endpoint = "/api/v1/youtube/web/get_video_subtitles"
        data = await self.client.fetch_get_json(f"{endpoint}?id={id}&format={format}")
        return data

    # 获取视频评论 | Get video comments
    async def get_video_comments(self, id: str, continuation: str = None, sort_by: str = None):
        endpoint = "/api/v1/youtube/web/get_video_comments"
        data = await self.client.fetch_get_json(f"{endpoint}?id={id}&continuation={continuation}&sort_by={sort_by}")
        return data

    # 获取短视频信息 | Get short video information
    async def get_short_video_info(self, id: str):
        endpoint = "/api/v1/youtube/web/get_short_video_info"
        data = await self.client.fetch_get_json(f"{endpoint}?id={id}")
        return data




# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class HybridParsing:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 抖音TikTok的混合解析 | Hybrid parsing of Douyin and TikTok
    async def video_data(self, url: str, minimal: bool = False, base64_url: bool = False):
        endpoint = "/api/v1/hybrid/video_data"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}&minimal={minimal}&base64_url={base64_url}")
        return data
